# ACE markdown editor directive example

You must run this example on the Django server, not from the local filesystem. The widget works when loaded via the local file system, but the toolbar icons do not load.

Heading Heading Heading
Bold Italic
Bulletlist Numbered list
# A heading Check out the Ace live [demo](http://ajaxorg.github.com/ace/) or get a [Cloud9 IDE account](http://run.cloud9ide.com) to experience Ace while editing one of your own GitHub projects. ``` python def sum(a, b): return a + b ```